"""Git-related configuration file management.

Provides .gitignore (GitHub Python patterns + pyrig-specific) and
prek.toml (local hooks for ruff, ty, bandit, rumdl) to maintain
code quality and prevent committing unwanted files.

Modules:
    gitignore: .gitignore file configuration management
    pre_commit: prek.toml file configuration management

See Also:
    GitHub gitignore templates: https://github.com/github/gitignore
    prek: https://github.com/j178/prek
"""
